
/* A MONTE CARLO STUDY
OBJECTIVE: TO COMPARE PERFORMANCE OF FOUR TREATMENT TESTS:
independent samples t-test
Mann-whitney test
Kolmogorov-Smirnoff test
Epps-Singleton Test
TREATMENT EFFECT = delta
NULL HYPOTHESIS: delta=0
*/

*FIRST RUN SINGLE SIMULATION:

clear

        set obs 100
		set seed 654321
		
* SET TRUE TREATMENT EFFECT
		
		scalar delta=0.0
		
		gen d=_n>(_N/2)
		
		* choose distributional assumption
		
		gen normal=rnormal()
		gen unif=runiform(-2,2)
		gen skew=(rchi2(3)-3)/sqrt(6)
		
		gen x=10+delta*d+unif
		ttest x, by(d)
		return list
		ranksum x, by(d)
		return list
		ksmirnov x, by(d)
		return list
						
*monte carlo:

clear
prog drop _all

   program define treatment_monte, rclass
        syntax [, obs(integer 1)  ]
        drop _all
		set obs `obs'
		tempvar x 
		
		gen d=_n>(_N/2)
		
		gen normal=rnormal()
		gen unif=runiform(-2,2)
		gen skew=(rchi2(3)-3)/sqrt(6)
		
		gen x=10+delta*d+skew
		
		ttest x, by(d)
		return scalar ttest_p = r(p)
		ranksum x, by(d)
		return scalar mw_p=(2*normal(r(z)))*(r(z)<0.5)+(2*normal(-r(z)))*(r(z)>0.5)
 		ksmirnov x, by(d)
		return scalar ks_p = r(p)
		
		escftest x, group(d)
		return scalar es_p=r(p_val)
        
	    end


* FIND SIZE OF EACH TEST (i.e. PROPORTION OF REJECTIONS WHEN delta = 0)
		
scalar delta=0.00		
simulate ttest_p=r(ttest_p) mw_p=r(mw_p) ks_p=r(ks_p) es_p=r(es_p) , reps(1000)  : treatment_monte, obs(100)

gen reject_ttest=ttest_p<0.05
gen reject_mw=mw_p<0.05
gen reject_ks=ks_p<0.05
gen reject_es=es_p<0.05

* FIND SIZE OF THE THREE TESTS:

summ reject*

* TEST FOR UNBIASEDNESS(ACTUAL SIZE = NOMINAL SIZE):

bitest reject_ttest=0.05
bitest reject_mw=0.05
bitest reject_ks=0.05
bitest reject_es=0.05

* FIND POWER OF EACH TEST (i.e. PROPORTION OF REJECTIONS WHEN delta > 0)
		
scalar delta=0.50		
simulate ttest_p=r(ttest_p) mw_p=r(mw_p) ks_p=r(ks_p) es_p=r(es_p) , reps(1000)  : treatment_monte, obs(100)

gen reject_ttest=ttest_p<0.05
gen reject_mw=mw_p<0.05
gen reject_ks=ks_p<0.05
gen reject_es=es_p<0.05

* FIND POWER OF THE THREE TESTS:

summ reject*


* FIND POWER OF ABOVE INDEPENDENT SAMPLES T-TEST (when true effect size =0.5)
*  USING POWER COMMAND:

power twomeans 10 10.5 , sd(1) n(100)


