


* PART 3: ESTIMATION OF RISK AVERSION PARAMETERS

* MODELLING CHOICES BETWEEN LOTTERIES (THE HOUSE MONEY EFFECT)

use "house_money_sim", clear
set more off

* TABLE SHOWING PROPORTION OF SAFE CHOICES AT EACH WEALTH LEVEL:

table w, contents(n y mean y)

* THE PROBIT MODEL AND WALD TEST; STORE ESTIMATES FOR LATER USE:

probit y w
test w=0
est store with_w

* GRAPH OF PREDICTED PROBABILITY OF SAFE CHOICE AGAINST WEALTH

margins, at(w=(0(1)15))
marginsplot, ylabel(0(0.1)1) yline(0.5)
 
*  MARGINAL EFFECTS

margins, dydx(w) at(w=0)
margins, dydx(w) at(w=10)
margins, dydx(w) 

*  LR TEST

probit y
est store without_w

lrtest with_w without_w

*  ANALYSIS OF ULTIMATUM GAME DATA

use ug_sim, clear

* ANALYZE RESPONDER'S DECISION AND COMPUTE MIMIMUM ACCEPTABLE OFFER:

tab d
lowess d y
probit d y
nlcom MAO: -_b[_cons]/_b[y]

* THE STRATEGY METHOD

use ug_sm_sim, clear

* NOTE: WHICH OF THE NEXT TWO COMMANDS WORKS DEPENDS ON WHICH VERSION OF STATA YOU ARE USING

*ci MAO
ci means MAO

tab d


*  THE ML ROUTINE IN STATA

capture program drop myprobit
set more off

* LOG-LIKELIHOOD EVALUATION PROGRAM "myprobit" STARTS HERE:

program define myprobit

* SPECIFY NAME OF QUANTITY WHOSE SUM WE WISH TO MAXIMISE (logl)
* AND ALSO PARAMETER NAMES (EMBODIED IN xb)
* PROVIDE LIST OF TEMPORARY VARIABLES (p ONLY)

	args logl xb
	tempvar p 

* GENERATE PROBABILITY OF CHOICE MADE BY EACH SUBJECT (p):	
	
	quietly gen double `p'=normal(yy*`xb')
	
* TAKE NATURAL LOG OF p AND STORE THIS AS logl
	
	quietly replace `logl'=ln(`p')
	
* END "myprobit" PROGRAM:	
	
	end

* READ DATA	

use "house_money_sim", clear

* GENERATE (INTEGER) yy FROM y:

gen int yy=2*y-1

* SPECIFY LIKELIHOOD EVALUATOR (lf), EVALUATION PROGRAM (myprobit), 
* AND EXPLANATORY VARIABLE LIST.
* RUN MAXIMUM LIKELIHOOD PROCEDURE
	
ml model lf myprobit ( = w)
ml maximize

*  STRUCTURAL MODELLING

capt program drop structural
program structural
	args logl r sig
	tempvar eus eur diff p 

	quietly gen double `eus'=(w+5)^(1-`r')/(1-`r')
	quietly gen double `eur'=0.5*w^(1-`r')/(1-`r')+0.5*(w+10)^(1-`r')/(1-`r')
	quietly gen double `diff'=(`eus'-`eur')/`sig'
	quietly gen double `p'=normal(yy*`diff')
	quietly replace `logl'=ln(`p')
	end

ml model lf structural /r  /sig
ml maximize


* THE HETEROGENEOUS AGENT MODEL

use holtlaury_sim, clear

probit y rstar

nlcom (mu: -_b[_cons]/_b[rstar]) (sig: -1/_b[rstar])

mat V=e(V)
mat list V

*  INTERVAL DATA

use "interval_data_sim", clear

intreg rlower rupper

intreg rlower rupper age male

*   EXACT DATA

use "exact_sim", clear

hist r

program define exact
	args lnf xb sig
	tempvar y p

	quietly gen double `y'=$ML_y1
	quietly gen double `p'=(1/`sig')*normalden((`y'-`xb')/`sig')
	quietly replace `lnf'=ln(`p')
	end

ml model lf exact (r= ) () 
ml maximize

summ r



*  THE ULTIMATUM GAME: FURTHER ANALYSIS

use ug_sim, clear

gen m_to_f=male_i*(1-male_j)

regress y male_i male_j m_to_f

probit d y male_j

nlcom more_to_male: -_b[male_j]/_b[y]

gen egal=y==50
tab egal

tab male_i egal , chi2

